==> ercore-9.1.8-beta1.tar.gz: ercore/modules/ercore_core/src/Form/ERCoreTableEExpanded.php <==
<?php

namespace Drupal\ercore_core\Form;

/**
 * @file
 * Contains Drupal\ercore\Form\ERCoreTableE.
 */

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\ercore_core\ErcoreOutputsExpanded; // ! change this
use Drupal\Core\Link;
use Drupal\Core\Url;

/**
 * Class ERCoreTableEExpanded.
 *
 * Defines ERCore Table E expanded.
 *
 * @package Drupal\ercore\Form
 */
class ERCoreTableEExpanded extends FormBase
{

  /**
   * {@inheritdoc}
   */
    public function getFormId()
    {
        return 'ERCoreTableE';
    }

    /**
     * {@inheritdoc}
     */
    public function buildForm(array $form, FormStateInterface $form_state)
    {
        // dpr(ErcoreOutputsExpanded::getPatents()); // ! NEW
        // dpm(ErcoreOutputsExpanded::filteredPatents()); // ! NEW
        
        // $url = Url::fromRoute('ercore_core.collaborations_export');
        // $link = Link::fromTextAndUrl('Download NSF Table C.', $url);
        $form['#attached']['library'][] = 'ercore_core/ercore-core-exports.library';
        $content_type=$_GET["contenttype"];
        $cat=$_GET["cat"];
        $type=$_GET["type"];
        // dpm($_GET["cumulative"]);
        // $cumulative=boolval($_GET["cumulative"]);
        $cumulative=(int)filter_var($_GET["cumulative"], FILTER_VALIDATE_BOOLEAN);
        // dpm($cumulative);
        $nodetype=$_GET["nodetype"];

        $cats2 = array(
          "academic_research_institutions" => "Academic Research Institutions",
          "primarily_undergraduate_institutions" => "Primarily Undergraduate Institutions",
          "historically_black_colleges_and_universities" => "Historically Black Colleges and Universities",
        );
// ! ---------------------------------------put into own function------------------------------------------------ 
// ! need to make a parameter that determines if the patents are filtered or cumulative
        if ($content_type=='patents') {
            $form = self::build_patents($type, $cumulative, $form);
//! ---------------------------------------put into own function------------------------------------------------ 

        } else if ($content_type=='proposals_grants') {
            $form = self::build_proposals_grants($type, $cumulative, $form);
            // $form['data_table'] = [
            //     '#type' => 'fieldset',
            //     '#title' => t($types[$type]." > ".$cats2[$cat]. ' > Collaborators'),
            //     '#open' => true,
            // ];
        }

        // if ($_GET["nodetype"]=='institutions') {
        //     $form['data_table'] = [
        //         '#type' => 'fieldset',
        //         '#title' => t($types[$type]." > ".$cats2[$cat]. ' > Institutions'),
        //         '#open' => true,
        //     ];
        // } else {
        //     $form['data_table'] = [
        //         '#type' => 'fieldset',
        //         '#title' => t($types[$type]." > ".$cats2[$cat]. ' > Collaborators'),
        //         '#open' => true,
        //     ];
        // }

        // $form['data_table']['description'] = [
        // //   '#markup' => self::formatResults(),
        // ];

        // $form['export_link'] = [
        // '#markup' => '<p class="epscor-download">' . $link->toString() . '</p>',
        // ];
        return $form;
    }

    public function build_patents($type, $cumulative, $form){
        $patent_categories = array(
            "licensed" => "Licensed",
            "awarded" => "Awarded",
            "pending" => "Pending",
          );
        $form['data_table'] = [
            '#type' => 'fieldset',
            '#title' => t($patent_categories[$type].' > Patents'),
            '#open' => true,
        ];
        $patents = ErcoreOutputsExpanded::filteredPatents($cumulative);
        $results = '';
        if($type == 'awarded'){
            foreach ($patents["awarded"] as $key => $value) {
                // $results .='<h2>'.$key.'</h2>';
                $results .= '<a href="/node/' . $key . '">' . '<h2>'.$value.'</h2>' . '</a>';
                // $results .= '<h4 class="indent30">Collaborations:</h4>';
                // foreach ($patents[$key]['collabs'] as $key => $value) {
                //     $results .= '<div class="indent60"><a  href="/node/' . $value . '">' .$key . '</a></div>';
                // }
            }
            foreach ($patents["licensed"] as $key => $value) {
                // $results .='<h2>'.$key.'</h2>';
                $results .= '<a href="/node/' . $key . '">' . '<h2>'.$value.'</h2>' . '</a>';
                // $results .= '<h4 class="indent30">Collaborations:</h4>';
                // foreach ($patents[$key]['collabs'] as $key => $value) {
                //     $results .= '<div class="indent60"><a  href="/node/' . $value . '">' .$key . '</a></div>';
                // }
            }
            $form['data_table']['description'] = [
                '#markup' => $results
            ];
        }
        elseif($type == 'licensed'){
            foreach ($patents["licensed"] as $key => $value) {
                // $results .='<h2>'.$key.'</h2>';
                $results .= '<a href="/node/' . $key . '">' . '<h2>'.$value.'</h2>' . '</a>';
                // $results .= '<h4 class="indent30">Collaborations:</h4>';
                // foreach ($patents[$key]['collabs'] as $key => $value) {
                //     $results .= '<div class="indent60"><a  href="/node/' . $value . '">' .$key . '</a></div>';
                // }
            }
            $form['data_table']['description'] = [
                '#markup' => $results
            ];
        }
        elseif($type == 'pending'){
            foreach ($patents["pending"] as $key => $value) {
                // $results .='<h2>'.$key.'</h2>';
                $results .= '<a href="/node/' . $key . '">' . '<h2>'.$value.'</h2>' . '</a>';
                // $results .= '<h4 class="indent30">Collaborations:</h4>';
                // foreach ($patents[$key]['collabs'] as $key => $value) {
                //     $results .= '<div class="indent60"><a  href="/node/' . $value . '">' .$key . '</a></div>';
                // }
            }
            $form['data_table']['description'] = [
                '#markup' => $results
            ];
        }
        return $form;
    }

    public function build_proposals_grants($type, $cumulative, $form){
        $proposal_categories = array(
            "submitted" => "Submitted",
            "awarded" => "Awarded",
            "pending" => "Pending",
          );
        $form['data_table'] = [
            '#type' => 'fieldset',
            '#title' => t($proposal_categories[$type].' > Proposals / Grants/ Contracts'),
            '#open' => true,
        ];
        $proposals = ErcoreOutputsExpanded::filteredProposals($cumulative);
        if($cumulative == TRUE){
            $proposals = ErcoreOutputsExpanded::getProposals($cumulative);
        }
        // dpm($proposals);
        $results = '';
        if($type == 'awarded'){
            foreach ($proposals["awarded"] as $key => $value) {
                $results .= '<a href="/node/' . $key . '">' . '<h2>'.$value.'</h2>' . '</a>';
            }
            $form['data_table']['description'] = [
                '#markup' => $results
            ];
        }
        elseif($type == 'submitted'){
            foreach ($proposals["submitted"] as $key => $value) {
                $results .= '<a href="/node/' . $key . '">' . '<h2>'.$value.'</h2>' . '</a>';
            }
            $form['data_table']['description'] = [
                '#markup' => $results
            ];
        }
        elseif($type == 'pending'){
            foreach ($proposals["pending"] as $key => $value) {
                $results .= '<a href="/node/' . $key . '">' . '<h2>'.$value.'</h2>' . '</a>';
            }
            $form['data_table']['description'] = [
                '#markup' => $results
            ];
        }
        return $form;
    }

    /**
     * {@inheritdoc}
     */
    public function submitForm(array &$form, FormStateInterface $form_state)
    {
        // We don't use this, but the interface requires us to implement it.
    }

    /**
     * Format Results.
     */
    public function formatResults()
    {
        $cat=$_GET["cat"];
        $type=$_GET["type"];
        $nodetype=$_GET["nodetype"];
        $cats = array(
            "academic_research_institutions" => "academic",
            "primarily_undergraduate_institutions" => "undergrad",
            "historically_black_colleges_and_universities" => "black",
            "hispanic_serving_institutions" => "hispanic",
            "tribal_colleges_and_universities" => "tribal",
            "national_laboratories" => "lab",
            "industry" => "industry",
            "none_other" => "none",
            "totals" => "totals"
        );

        $data = ErcoreOutputsExpanded::getData($cats[$cat], $type, $nodetype);
        $results = '';
        if ($nodetype=='institutions') {
            foreach ($data as $key => $value) {
                // $results .='<h2>'.$key.'</h2>';
                $results .= '<a href="/node/' . $data[$key]['id'] . '">' . '<h2>'.$key.'</h2>' . '</a>';
                $results .= '<h4 class="indent30">Collaborations:</h4>';
                foreach ($data[$key]['collabs'] as $key => $value) {
                    $results .= '<div class="indent60"><a  href="/node/' . $value . '">' .$key . '</a></div>';
                }

            }
        }
        if ($nodetype=='collaborator') {
            $num=1;
            foreach ($data as $key => $value) {
                $results .='<h2>'.$key.'</h2>';
                // $results .= '<a href="/node/' . $data[$key]['id'] . '">' . '<h2>'.$key.'</h2>' . '</a>';
                $results .= '<span class="indent30">Institution:'.'<a href="/node/' . $data[$key]['id'] . '">' . $data[$key]['institution']. '</a></span>';
                $results .= '<h4 class="indent30">Collaborations:</h4>';
                foreach ($data[$key]['collabs'] as $key => $value) {
                    $results .= '<div class="indent60"><a  href="/node/' . $value . '">' .$key . '</a>  Count Number:'.$num.'</div>';
                    $num++;
                }
            }

            
        }
    
        if ($nodetype=='collaborator2') {
            $data = ErcoreOutputsExpanded::getData($cats[$cat], $type, 'collaborator');
            $num=1;
            foreach ($data as $key => $value) {
                foreach ($data[$key]['collabs'] as $key2 => $value2) {
                    $results .='<h2>'.$key.'</h2>';
                    $results .= '<span class="indent30">Institution:'.'<a href="/node/' . $data[$key]['id'] . '">' . $data[$key]['institution']. '</a></span><div></div>';
                    $results .= '<span class="indent30">Collaboration:<a  href="/node/' . $value2 . '">' .$key2 . '</a></span>';
      
                    $num++;
                }
            }
        }

       
        return $results;
    }
}

==> ercore-10.1.5-beta1.tar.gz: ercore/modules/ercore_core/src/Form/ERCoreTableEExpanded.php <==
<?php

namespace Drupal\ercore_core\Form;

/**
 * @file
 * Contains Drupal\ercore\Form\ERCoreTableE.
 */

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\ercore_core\ErcoreOutputsExpanded; // ! change this
use Drupal\Core\Link;
use Drupal\Core\Url;

/**
 * Class ERCoreTableEExpanded.
 *
 * Defines ERCore Table E expanded.
 *
 * @package Drupal\ercore\Form
 */
class ERCoreTableEExpanded extends FormBase
{

  /**
   * {@inheritdoc}
   */
    public function getFormId()
    {
        return 'ERCoreTableE';
    }

    /**
     * {@inheritdoc}
     */
    public function buildForm(array $form, FormStateInterface $form_state)
    {
        // dpr(ErcoreOutputsExpanded::getPatents()); // ! NEW
        // dpm(ErcoreOutputsExpanded::filteredPatents()); // ! NEW
        
        // $url = Url::fromRoute('ercore_core.collaborations_export');
        // $link = Link::fromTextAndUrl('Download NSF Table C.', $url);
        $form['#attached']['library'][] = 'ercore_core/ercore-core-exports.library';
        $content_type=$_GET["contenttype"];
        $cat=$_GET["cat"];
        $type=$_GET["type"];
        // dpm($_GET["cumulative"]);
        // $cumulative=boolval($_GET["cumulative"]);
        $cumulative=(int)filter_var($_GET["cumulative"], FILTER_VALIDATE_BOOLEAN);
        // dpm($cumulative);
        $nodetype=$_GET["nodetype"];

        $cats2 = array(
          "academic_research_institutions" => "Academic Research Institutions",
          "primarily_undergraduate_institutions" => "Primarily Undergraduate Institutions",
          "historically_black_colleges_and_universities" => "Historically Black Colleges and Universities",
        );
// ! ---------------------------------------put into own function------------------------------------------------ 
// ! need to make a parameter that determines if the patents are filtered or cumulative
        if ($content_type=='patents') {
            $form = self::build_patents($type, $cumulative, $form);
//! ---------------------------------------put into own function------------------------------------------------ 

        } else if ($content_type=='proposals_grants') {
            $form = self::build_proposals_grants($type, $cumulative, $form);
            // $form['data_table'] = [
            //     '#type' => 'fieldset',
            //     '#title' => t($types[$type]." > ".$cats2[$cat]. ' > Collaborators'),
            //     '#open' => true,
            // ];
        }

        else if ($content_type=='publications') {
            $form = self::build_publications($type, $cumulative, $form);
        }

        else if ($content_type=='hired') {
            $form = self::build_users($content_type, $type, $cumulative, $form);
        }

        else if ($content_type=='post-doc') {
            $form = self::build_users($content_type, $type, $cumulative, $form);
        }

        else if ($content_type=='graduate') {
            $form = self::build_users($content_type, $type, $cumulative, $form);
        }

        else if ($content_type=='undergraduate') {
            $form = self::build_users($content_type, $type, $cumulative, $form);
        }

        return $form;
    }

    public function build_patents($type, $cumulative, $form){
        $patent_categories = array(
            "licensed" => "Licensed",
            "awarded" => "Awarded",
            "pending" => "Pending",
          );
        $form['data_table'] = [
            '#type' => 'fieldset',
            '#title' => t($patent_categories[$type].' > Patents'),
            '#open' => true,
        ];
        $patents = ErcoreOutputsExpanded::filteredPatents($cumulative);
        $results = '';
        if($type == 'awarded'){
            foreach ($patents["awarded"] as $key => $value) {
                // $results .='<h2>'.$key.'</h2>';
                $results .= '<a href="/node/' . $key . '">' . '<h2>'.$value.'</h2>' . '</a>';
                // $results .= '<h4 class="indent30">Collaborations:</h4>';
                // foreach ($patents[$key]['collabs'] as $key => $value) {
                //     $results .= '<div class="indent60"><a  href="/node/' . $value . '">' .$key . '</a></div>';
                // }
            }
            foreach ($patents["licensed"] as $key => $value) {
                // $results .='<h2>'.$key.'</h2>';
                $results .= '<a href="/node/' . $key . '">' . '<h2>'.$value.'</h2>' . '</a>';
                // $results .= '<h4 class="indent30">Collaborations:</h4>';
                // foreach ($patents[$key]['collabs'] as $key => $value) {
                //     $results .= '<div class="indent60"><a  href="/node/' . $value . '">' .$key . '</a></div>';
                // }
            }
            $form['data_table']['description'] = [
                '#markup' => $results
            ];
        }
        elseif($type == 'licensed'){
            foreach ($patents["licensed"] as $key => $value) {
                // $results .='<h2>'.$key.'</h2>';
                $results .= '<a href="/node/' . $key . '">' . '<h2>'.$value.'</h2>' . '</a>';
                // $results .= '<h4 class="indent30">Collaborations:</h4>';
                // foreach ($patents[$key]['collabs'] as $key => $value) {
                //     $results .= '<div class="indent60"><a  href="/node/' . $value . '">' .$key . '</a></div>';
                // }
            }
            $form['data_table']['description'] = [
                '#markup' => $results
            ];
        }
        elseif($type == 'pending'){
            foreach ($patents["pending"] as $key => $value) {
                // $results .='<h2>'.$key.'</h2>';
                $results .= '<a href="/node/' . $key . '">' . '<h2>'.$value.'</h2>' . '</a>';
                // $results .= '<h4 class="indent30">Collaborations:</h4>';
                // foreach ($patents[$key]['collabs'] as $key => $value) {
                //     $results .= '<div class="indent60"><a  href="/node/' . $value . '">' .$key . '</a></div>';
                // }
            }
            $form['data_table']['description'] = [
                '#markup' => $results
            ];
        }
        return $form;
    }

    public function build_proposals_grants($type, $cumulative, $form){
        $proposal_categories = array(
            "submitted" => "Submitted",
            "awarded" => "Awarded",
            "pending" => "Pending",
          );
        $form['data_table'] = [
            '#type' => 'fieldset',
            '#title' => t($proposal_categories[$type].' > Proposals / Grants/ Contracts'),
            '#open' => true,
        ];
        $proposals = ErcoreOutputsExpanded::filteredProposals($cumulative);
        if($cumulative == TRUE){
            $proposals = ErcoreOutputsExpanded::getProposals($cumulative);
        }
        // dpm($proposals);
        $results = '';
        if($type == 'awarded'){
            foreach ($proposals["awarded"] as $key => $value) {
                $results .= '<a href="/node/' . $key . '">' . '<h2>'.$value.'</h2>' . '</a>';
            }
            $form['data_table']['description'] = [
                '#markup' => $results
            ];
        }
        elseif($type == 'submitted'){
            foreach ($proposals["submitted"] as $key => $value) {
                $results .= '<a href="/node/' . $key . '">' . '<h2>'.$value.'</h2>' . '</a>';
            }
            $form['data_table']['description'] = [
                '#markup' => $results
            ];
        }
        elseif($type == 'pending'){
            foreach ($proposals["pending"] as $key => $value) {
                $results .= '<a href="/node/' . $key . '">' . '<h2>'.$value.'</h2>' . '</a>';
            }
            $form['data_table']['description'] = [
                '#markup' => $results
            ];
        }
        return $form;
    }

    public function build_publications($type, $cumulative, $form){
        $publication_categories = array(
            "primary" => "Primary RII Support",
            "partial" => "Partial RII Support",
          );
        $form['data_table'] = [
            '#type' => 'fieldset',
            '#title' => t($publication_categories[$type].' > Publications'),
            '#open' => true,
        ];
        $publications = ErcoreOutputsExpanded::filteredPublications($cumulative);
        $results = '';
        if($type == 'primary'){
            foreach ($publications["primary"] as $key => $value) {
                $results .= '<a href="/node/' . $key . '">' . '<h2>'.$value.'</h2>' . '</a>';
            }
            $form['data_table']['description'] = [
                '#markup' => $results
            ];
        }
        elseif($type == 'partial'){
            foreach ($publications["partial"] as $key => $value) {
                $results .= '<a href="/node/' . $key . '">' . '<h2>'.$value.'</h2>' . '</a>';
            }
            $form['data_table']['description'] = [
                '#markup' => $results
            ];
        }
        return $form;
    }

    public function build_users($type, $cat, $cumulative, $form){
        $user_categories = array(
            "male" => "Male",
            "female" => "Female",
            "minority" => "Underrepresented Minority",
            "disabled" => "Disabled",
        );
        $user_academic_categories = array(
            'hired' => 'New Faculty Hired',
            'post-doc' => 'Post Docs Invlolved',
            'graduate' => 'Graduate Students Graduated',
            'undergraduate' => 'Undergraduates Graduated',
        );
        $form['data_table'] = [
            '#type' => 'fieldset',
            '#title' => t($user_categories[$cat].' > '.$user_academic_categories[$type]),
            '#open' => true,
        ];
        $users = ErcoreOutputsExpanded::filteredUsers($cumulative, $type);
        // /user/id
        $results = '';
        if($cat == 'male'){
            if($cumulative == TRUE){
                foreach ($users[$type]["male"]["cumulative"] as $key => $value) {
                    $results .= '<a href="/user/' . $value["id"] . '">' . '<h2>'.$value["name"].'</h2>' . '</a>';
                }
            }
            else{
                foreach ($users[$type]["male"]["current"] as $key => $value) {
                    $results .= '<a href="/user/' . $value["id"] . '">' . '<h2>'.$value["name"].'</h2>' . '</a>';
                }
            }
            $form['data_table']['description'] = [
                '#markup' => $results
            ];
        }
        elseif($cat == 'female'){
            if($cumulative == TRUE){
                foreach ($users[$type]["female"]["cumulative"] as $key => $value) {
                    $results .= '<a href="/user/' . $value["id"] . '">' . '<h2>'.$value["name"].'</h2>' . '</a>';
                }
            }
            else{
                foreach ($users[$type]["female"]["current"] as $key => $value) {
                    $results .= '<a href="/user/' . $value["id"] . '">' . '<h2>'.$value["name"].'</h2>' . '</a>';
                }
            }
            $form['data_table']['description'] = [
                '#markup' => $results
            ];
        }
        elseif($cat == 'minority'){
            if($cumulative == TRUE){
                foreach ($users[$type]["minority"]["cumulative"] as $key => $value) {
                    $results .= '<a href="/user/' . $value["id"] . '">' . '<h2>'.$value["name"].'</h2>' . '</a>';
                }
            }
            else{
                foreach ($users[$type]["minority"]["current"] as $key => $value) {
                    $results .= '<a href="/user/' . $value["id"] . '">' . '<h2>'.$value["name"].'</h2>' . '</a>';
                }
            }
            $form['data_table']['description'] = [
                '#markup' => $results
            ];
        }
        elseif($cat == 'disabled'){
            if($cumulative == TRUE){
                foreach ($users[$type]["disabled"]["cumulative"] as $key => $value) {
                    $results .= '<a href="/user/' . $value["id"] . '">' . '<h2>'.$value["name"].'</h2>' . '</a>';
                }
            }
            else{
                foreach ($users[$type]["disabled"]["current"] as $key => $value) {
                    $results .= '<a href="/user/' . $value["id"] . '">' . '<h2>'.$value["name"].'</h2>' . '</a>';
                }
            }
            $form['data_table']['description'] = [
                '#markup' => $results
            ];
        }
        return $form;
    }

    /**
     * {@inheritdoc}
     */
    public function submitForm(array &$form, FormStateInterface $form_state)
    {
        // We don't use this, but the interface requires us to implement it.
    }

}
